==> toucan_connectors-0.21.1.tar.gz: toucan_connectors-0.21.1/toucan_connectors/google_spreadsheet/google_spreadsheet_connector.py <==
from typing import List

import gspread
import pandas as pd
from oauth2client.service_account import ServiceAccountCredentials

from toucan_connectors.toucan_connector import ToucanConnector, ToucanDataSource
from toucan_connectors.google_credentials import GoogleCredentials


class GoogleSpreadsheetDataSource(ToucanDataSource):
    spreadsheet_id: str
    sheetname: str = None
    skip_rows: int = 0


class GoogleSpreadsheetConnector(ToucanConnector):
    """
    For authentication, download an authentication file from console.developper.com
    and use the values here. This is an oauth2 credential file. For more information
    see this: http://gspread.readthedocs.io/en/latest/oauth2.html
    """
    data_source_model: GoogleSpreadsheetDataSource

    credentials: GoogleCredentials
    scope: List[str] = ['https://www.googleapis.com/auth/drive',
                        'https://www.googleapis.com/auth/spreadsheets',
                        'https://spreadsheets.google.com/feeds']

    def _retrieve_data(self, data_source):
        credentials = ServiceAccountCredentials.from_json_keyfile_dict(
            self.credentials.dict(),
            self.scope
        )
        gc = gspread.authorize(credentials)

        sheets = gc.open_by_key(data_source.spreadsheet_id)
        sheetname = data_source.sheetname
        sheet = sheets.sheet1 if sheetname is None else sheets.worksheet(sheetname)
        starting_row = 1 + data_source.skip_rows
        records = sheet.get_all_records(head=starting_row)
        df = pd.DataFrame(records)
        return df

==> toucan_connectors-0.25.0.tar.gz: toucan_connectors-0.25.0/toucan_connectors/google_spreadsheet/google_spreadsheet_connector.py <==
from typing import List

import gspread
import pandas as pd
from oauth2client.service_account import ServiceAccountCredentials

from toucan_connectors.google_credentials import GoogleCredentials
from toucan_connectors.toucan_connector import ToucanConnector, ToucanDataSource


class GoogleSpreadsheetDataSource(ToucanDataSource):
    spreadsheet_id: str
    sheetname: str = None
    skip_rows: int = 0


class GoogleSpreadsheetConnector(ToucanConnector):
    """
    For authentication, download an authentication file from console.developper.com
    and use the values here. This is an oauth2 credential file. For more information
    see this: http://gspread.readthedocs.io/en/latest/oauth2.html
    """

    data_source_model: GoogleSpreadsheetDataSource

    credentials: GoogleCredentials
    scope: List[str] = [
        'https://www.googleapis.com/auth/drive',
        'https://www.googleapis.com/auth/spreadsheets',
        'https://spreadsheets.google.com/feeds',
    ]

    def _retrieve_data(self, data_source):
        credentials = ServiceAccountCredentials.from_json_keyfile_dict(
            self.credentials.dict(), self.scope
        )
        gc = gspread.authorize(credentials)

        sheets = gc.open_by_key(data_source.spreadsheet_id)
        sheetname = data_source.sheetname
        sheet = sheets.sheet1 if sheetname is None else sheets.worksheet(sheetname)
        starting_row = 1 + data_source.skip_rows
        records = sheet.get_all_records(head=starting_row)
        df = pd.DataFrame(records)
        return df
